#
# spec file for package kubectl-view-allocations
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'

Name:           kubectl-view-allocations
Version:        0.22.0
Release:        1.1
Summary:        kubectl plugin to list allocations
License:        CC0-1.0
URL:            https://github.com/davidB/kubectl-view-allocations
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Recommends:     fzf
BuildRequires:  cargo
# kube-client v0.90.0 requires rust 1.75 or higher
BuildRequires:  rust >= 1.75.0

%description
kubectl plugin lists allocations for resources (cpu, memory, gpu,...) as
defined into the manifest of nodes and running pods. It doesn't list usage like
kubectl top. It can provide result grouped by namespaces, nodes, pods and
filtered by resources'name.

Columns displayed :

* Requested : Quantity of resources requested by the container in the pod's manifest. It's the sum group by pod, namespace, node where container is running. With percentage of resources requested over what is allocatable in the group.
* Limit : Quantity of resources max (limit) requestable by the container in the pod's manifest. It's the sum group by pod, namespace, node where container is running. With percentage of resources max / limit over what is allocatable in the group.
* Allocatable : Allocatable resources defined (or detected) on nodes.
* Free : Allocatable - max (Limit, Requested)
* Utilization : Quantity of resources (cpu & memory only) used as reported by Metrics API. It's disable by default, metrics-server is optional and should be setup into the cluster.

%prep
%autosetup -a1

%build
RUSTFLAGS=%{rustflags} cargo build --release --all-features

%install
RUSTFLAGS=%{rustflags} cargo install --root=%{buildroot}%{_prefix} --path .
rm -f %{buildroot}/usr/.crates.toml
rm -f %{buildroot}/usr/.crates2.json

# make this available as a kubectl plugin
cd %{buildroot}/%{_bindir}/
ln -s ./%{name} ./kubectl-view_allocations

%files
%license LICENSE.txt
%{_bindir}/%{name}
%{_bindir}/kubectl-view_allocations

%changelog
* Mon Jun 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.22.0:
  * (cargo-release) version 0.22.0
  * Update cli's help
  * apply some clippy suggestion
  * Call `list` concurrently on every Pod's api
  * allow a list of namespaces to be passed
  * Bump clap from 4.5.39 to 4.5.40
* Tue Jun  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.21.2:
  * (cargo-release) version 0.21.2
  * Bump kube from 0.99.0 to 1.1.0
  * Bump color-eyre from 0.6.4 to 0.6.5
  * Bump tokio from 1.45.0 to 1.45.1
  * Bump clap from 4.5.38 to 4.5.39
  * add link to another alternative
* Sun May 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.21.1:
  * (cargo-release) version 0.21.1
  * `--show-zero` display unset cpu and memory for pods
* Sun May 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.21.0:
  * on cli, allow multi-value option to be defined as a list (with
    comma as separator)
  * look at pods only on selected nodes
  * minor update of README
  * add an option to calculate Free as Allocatable - Requested
  * upgrade to rust 1.86
  * Bump chrono from 0.4.40 to 0.4.41
  * Bump clap from 4.5.36 to 4.5.37
  * Bump anyhow from 1.0.97 to 1.0.98
  * Bump clap from 4.5.35 to 4.5.36
  * Bump tokio from 1.44.1 to 1.44.2
  * Bump clap from 4.5.34 to 4.5.35
  * Bump clap from 4.5.32 to 4.5.34 (#257)
  * Bump mozilla-actions/sccache-action from 0.0.8 to 0.0.9 (#256)
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.20.5 (there is no 0.20.4 release):
  * (cargo-release) version 0.20.5
  * switch back to ring
  * (cargo-release) version 0.20.4
  * Update kube requirement from 0.98 to 0.99 (#254)
  * add Cargo.lock back
  * Bump mozilla-actions/sccache-action from 0.0.7 to 0.0.8
* Thu Jan  9 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.20.3:
  * :rocket: (cargo-release) version 0.20.3
  * enable http-proxy and oidc support on kube access
* Wed Jan  8 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.20.2:
  * :rocket: (cargo-release) version 0.20.2
  * Update kube requirement from 0.97 to 0.98
  * :arrow_up: Update itertools requirement from 0.13 to 0.14
  * :arrow_up: Bump mozilla-actions/sccache-action from 0.0.6 to
    0.0.7
  * :arrow_up: Update kube requirement from 0.96 to 0.97
  * :arrow_up: Update thiserror requirement from 1.0 to 2.0
  * :arrow_up: Bump rajatjindal/krew-release-bot from 0.0.46 to
    0.0.47
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.1:
  * :rocket: (cargo-release) version 0.20.1
  * 👷 migrate to dtolnay/rust-toolchain +
    mozilla-actions/sccache-action
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.0:
  * :rocket: (cargo-release) version 0.20.0
  * ⬆️ upgrade kube-rs to 0.96
  * 👷 upgrade from `rtx` to `mise` (new name)
  * feat: add labels filter support
  * :arrow_up: Update itertools requirement from 0.12 to 0.13
* Tue Apr 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- BuildRequire cargo 1.75 aka rust 1.75 to avoid errors due to
- kube-client v0.90.0
* Tue Apr 23 2024 opensuse_buildservice@ojkastl.de
- fix boo#1223224
- Update to version 0.19.2 (skipping non-existing releases 0.19.0
  and 0.19.1):
  * (cargo-release) version 0.19.2
  * (cargo-release) version 0.19.1
  * (cargo-release) version 0.19.0
  * Update kube & k8s-openapi, minimal k8s version is 1.24
  * add socks5 support via the kube dependency
  * Bump actions/cache from 3 to 4
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubectl-view-allocations: kubectl plugin to list
  allocations (cpu, memory, gpu,... X utilization, requested,
  limit, allocatable,...)
